==> apemanlocale-5.0.18.tgz: package/lib/load.js <==
/**
 * Define a locale object.
 * @function load
 */
'use strict'

const evaljson = require('evaljson')

const inflection = require('inflection')
const stringcase = require('stringcase')

/** @lends load */
function load (src) {
  /**
   * Locale instance.
   * @param {string} keypath - Keypath of message resource.
   * @param {Object} options - optional settings.
   * @param {Object} options.vars - Dynamic variables.
   * @returns {?string} - Message
   */
  function l (keypath, options) {
    options = options || {}
    let $vars = l.$vars
    l.$vars = options.vars || {}
    let result = l
    for (let key of String(keypath).split('.')) {
      result = result && result[ key ]
    }
    delete l.$vars
    // noinspection Eslint
    l.__proto__.$vars = $vars // Restore $vars

    return result
  }

  // noinspection Eslint
  l.__proto__ = Object.assign(new Function(''), {
    $vars: {},
    $fallback: {},
    fallback (locale) {
      // noinspection Eslint
      l.__proto__.$fallback = locale
    },
    toJSON () {
      return Object.assign({}, l)
    }
  })

  let properties = Object.keys(src || {}).reduce((properties, name) => {
    return Object.assign(properties, {
      [name]: {
        get () {
          let { $vars, $fallback } = l
          let value = src[ name ]
          if (typeof value === 'undefined') {
            value = $fallback && $fallback[ name ]
          }
          let context = load.context
          return evaljson(value, context, src, { l, vars: $vars })
        },
        enumerable: true
      }
    })
  }, {})
  Object.defineProperties(l, properties)
  return l
}

Object.assign(load, {
  context: Object.assign({}, stringcase, inflection)
})

module.exports = load

==> apemanlocale-5.0.20.tgz: package/lib/load.js <==
/**
 * Define a locale object.
 * @function load
 */
'use strict'

const evaljson = require('evaljson')

const inflection = require('inflection')
const stringcase = require('stringcase')

/** @lends load */
function load (src) {
  /**
   * Locale instance.
   * @param {string} keypath - Keypath of message resource.
   * @param {Object} options - optional settings.
   * @param {Object} options.vars - Dynamic variables.
   * @returns {?string} - Message
   */
  function l (keypath, options) {
    options = options || {}
    let $vars = l.$vars
    l.$vars = options.vars || {}
    let result = l
    for (let key of String(keypath).split('.')) {
      result = result && result[ key ]
    }
    delete l.$vars
    // noinspection Eslint
    l.__proto__.$vars = $vars // Restore $vars

    return result
  }

  // noinspection Eslint
  l.__proto__ = Object.assign(new Function(''), {
    $vars: {},
    $fallback: {},
    fallback (locale) {
      // noinspection Eslint
      l.__proto__.$fallback = locale
    },
    toJSON () {
      return Object.assign({}, l.$fallback || {}, l)
    }
  })

  let properties = Object.keys(src || {}).reduce((properties, name) => {
    return Object.assign(properties, {
      [name]: {
        get () {
          let { $vars, $fallback } = l
          let value = src[ name ]
          if (typeof value === 'undefined') {
            value = $fallback && $fallback[ name ]
          }
          let context = load.context
          return evaljson(value, context, src, { l, vars: $vars })
        },
        enumerable: true
      }
    })
  }, {})
  Object.defineProperties(l, properties)
  return l
}

Object.assign(load, {
  context: Object.assign({}, stringcase, inflection)
})

module.exports = load
